@@ -1,7 +1,6 @@
 from django.db import models
 from django.utils.functional import cached_property
 from django.http import HttpResponse
-from django.template.response import TemplateResponse
 from django.conf import settings
 from wagtail.admin.edit_handlers import MultiFieldPanel, StreamFieldPanel
 from wagtail.images.edit_handlers import ImageChooserPanel
@@ -9,30 +8,34 @@ from wagtail.core.fields import StreamField
 from wagtail.core.models import Page
 from wagtail.snippets.blocks import SnippetChooserBlock
 from wagtail.admin.edit_handlers import FieldPanel
-from ..bakery.models import BuildableWagtailBakeryModel
-from ..amp.mixins import AmpMixin
-from ..amp.utils import amp_mode_active
-from .. import constants
-from ..blocks import \
-    MediaText, \
-    Text, \
-    Svg, \
-    Image, \
-    Cards, \
-    ButtonBlock, \
-    FirstContent, \
-    GridInfo, \
-    MediasLine, \
-    TimeLine, \
-    Buttons, \
-    Calendly, \
-    Articles, \
-    Embed, \
-    HowTo, \
-    FAQPage
-from ...loader import get_model
+from wagtail.core.utils import camelcase_to_underscore
+
+from webspace.cms.amp.mixins import AmpMixin
+from webspace.cms.amp.utils import amp_mode_active
+from webspace.cms import constants
+from webspace.cms.blocks.schemas import HowTo, FAQPage
+from webspace.cms.blocks.common import ButtonBlock
+from webspace.loader import get_model, get_class
+
+#  Classes
+
+ArticlesEntry = get_class('cms.blocks.entries', 'ArticlesEntry')
+ButtonsEntry = get_class('cms.blocks.entries', 'ButtonsEntry')
+CardsEntry = get_class('cms.blocks.entries', 'CardsEntry')
+EmbedEntry = get_class('cms.blocks.entries', 'EmbedEntry')
+FirstContentEntry = get_class('cms.blocks.entries', 'FirstContentEntry')
+GridInfoEntry = get_class('cms.blocks.entries', 'GridInfoEntry')
+ImageEntry = get_class('cms.blocks.entries', 'ImageEntry')
+MediaTextEntry = get_class('cms.blocks.entries', 'MediaTextEntry')
+MediasLineEntry = get_class('cms.blocks.entries', 'MediasLineEntry')
+SvgEntry = get_class('cms.blocks.entries', 'SvgEntry')
+TextEntry = get_class('cms.blocks.entries', 'TextEntry')
+TimeLineEntry = get_class('cms.blocks.entries', 'TimeLineEntry')
+CalendlyEntry = get_class('cms.blocks.entries', 'CalendlyEntry')
+SocialShare = get_class('cms.blocks.static', 'SocialShare')
 
 
+#  Models
 Menu = get_model('cms', 'Menu')
 IconSnippet = get_model('cms', 'IconSnippet')
 
@@ -50,7 +53,8 @@ class AGenericPage(Page):
     theme = models.CharField(
         choices=constants.THEME_CHOICES,
         default=constants.THEME_SPACE,
-        max_length=100
+        max_length=100,
+        help_text="Permet de changer le theme du header et du footer"
     )
 
     breadcrumb = models.BooleanField(
@@ -73,19 +77,20 @@ class AGenericPage(Page):
     ], blank=True)
 
     body = StreamField([
-        ('first_content', FirstContent()),
-        ('svg', Svg()),
-        ('image', Image()),
-        ('text', Text()),
-        ('cards', Cards()),
-        ('media_text', MediaText()),
-        ('grid_info', GridInfo()),
-        ('medias_line', MediasLine()),
-        ('timeline', TimeLine()),
-        ('buttons', Buttons()),
-        ('calendly', Calendly()),
-        ('articles', Articles()),
-        ('embed', Embed()),
+        ('first_content', FirstContentEntry()),
+        ('svg', SvgEntry()),
+        ('image', ImageEntry()),
+        ('text', TextEntry()),
+        ('cards', CardsEntry()),
+        ('media_text', MediaTextEntry()),
+        ('grid_info', GridInfoEntry()),
+        ('medias_line', MediasLineEntry()),
+        ('timeline', TimeLineEntry()),
+        ('buttons', ButtonsEntry()),
+        ('calendly', CalendlyEntry()),
+        ('articles', ArticlesEntry()),
+        ('embed', EmbedEntry()),
+        ('social_share', SocialShare())
     ], blank=True)
 
     footer = StreamField([
@@ -127,14 +132,8 @@ class AGenericPage(Page):
 
     def get_context(self, request, *args, **kwargs):
         context = super(AGenericPage, self).get_context(request)
-        context['env'] = settings.TYPENV
-        context['icons'] = {}
-        DEFAULT_LINK = '/static/webspace/img/svg/default.svg'
-        for icon in IconSnippet.objects.all():
-            context['icons'][icon.key] = {
-                'space': icon.space.url if icon.space else DEFAULT_LINK,
-                'light': icon.light.url if icon.light else DEFAULT_LINK,
-            }
+        context['debug'] = str(settings.DEBUG)
+        context['icons'] = IconSnippet.get_context()
         return context
 
     @cached_property
@@ -147,23 +146,6 @@ class AGenericPage(Page):
                 ret.append(item)
         return ret
 
-    def serve(self, request, *args, **kwargs):
-        is_building = request.GET.get('build', False)
-        request.is_preview = getattr(request, 'is_preview', False)
-
-        if settings.DEBUG or request.is_preview or is_building or not isinstance(self,
-                                                                                 BuildableWagtailBakeryModel):
-            return TemplateResponse(
-                request,
-                self.get_template(request, *args, **kwargs),
-                self.get_context(request, *args, **kwargs)
-            )
-        else:
-            return self.render_baked_file(
-                request,
-                settings.TEMPLATE_PATH + "/build" + self.get_url()
-            )
-
     def get_sitemap_urls(self, request=None):
         if not self.breadcrumb:
             return []
@@ -186,3 +168,9 @@ class AGenericPage(Page):
             response['Content-Encoding'] = 'gzip'
             response['Content-Length'] = str(len(compressed))
             return response
+
+    def get_template(self, request, *args, **kwargs):
+        return "%s/%s.html" % (
+            constants.PAGES_TEMPLATES_PATH,
+            camelcase_to_underscore(self.__class__.__name__)
+        )
