@@ -3,10 +3,12 @@ from wagtail.search import index
 from wagtail.admin.edit_handlers import FieldPanel
 from wagtail.documents.edit_handlers import DocumentChooserPanel
 
-from webspace.cms.models import MyDocument
 from webspace.loader import get_model
 
 
+MyDocument = get_model('cms', 'MyDocument')
+
+
 class AIconSnippet(index.Indexed, models.Model):
     key = models.CharField(max_length=255)
     light = models.ForeignKey(
